---
name: bug report
about: create a bug report for an unexpected behaviour
title: "[BUG]"
labels: bug
assignees: ''

---

### issue description
{describe what happened}

### steps to reproduce
{a step by step instruction}
{or a video with what keys you are pressing visualized}

### what is the expected result
{expected result}

### what actually happened
{actual result}

### how this could be fixed (optional)
{a rough way of how this could be fixed}
{this can be left out}

### additional screenshots (optional)
{more screenshots to the issue}
{this can be left out if you have a video attached}
